@@ -16,6 +16,12 @@ command_suite = (
             'x-configuration',
             'x_configuration'
         ),
+        (
+            'datalad_mihextras.export_to_webdav',
+            'ExportToWEBDAV',
+            'x-export-to-webdav',
+            'x_export_to_webdav'
+        ),
         (
             'datalad_mihextras.snakemake',
             'SnakeMake',
